import type { ActionsColumnProps, TableVariant, TdProps, ThProps } from "@patternfly/react-table";
import { ActionsColumn, Td, Th } from "@patternfly/react-table";
import type { PropsWithChildren, ReactElement } from "react";
export type RenderHeaderCb<TCol> = (props: {
    Th: typeof Th;
    key: string;
    column: TCol;
    colIndex: number;
}) => ReactElement<ResponsiveThProps>;
export type RenderCellCb<TRow, TCol> = (props: {
    Td: typeof Td;
    key: string;
    column: TCol;
    colIndex: number;
    rowIndex: number;
    row: TRow;
}) => ReactElement<ResponsiveTdProps>;
export type RenderActionsCb<TRow> = (props: {
    ActionsColumn: typeof ActionsColumn;
    row: TRow;
    rowIndex: number;
}) => ReactElement<ActionsColumnProps> | undefined;
export type ResponsiveTableProps<TRow, TCol> = {
    ariaLabel: string;
    minimumColumnWidth?: number;
    columns: readonly TCol[];
    data: TRow[] | undefined;
    renderHeader: RenderHeaderCb<TCol>;
    renderCell: RenderCellCb<TRow, TCol>;
    renderActions?: RenderActionsCb<TRow>;
    isColumnSortable?: (column: TCol) => (ResponsiveThProps["sort"] & {
        label: string;
    }) | undefined;
    isRowDeleted?: (props: RowProps<TRow>) => boolean;
    isRowSelected?: (props: RowProps<TRow>) => boolean;
    expectedLength?: number;
    onRowClick?: (props: RowProps<TRow>) => void;
    setActionCellOuiaId?: (props: RowProps<TRow>) => string;
    setRowOuiaId?: (props: RowProps<TRow>) => string;
    tableOuiaId?: string;
    variant?: TableVariant;
};
type RowProps<TRow> = {
    row: TRow;
    rowIndex: number;
};
export declare const ResponsiveTable: <TRow, TCol>({ ariaLabel, minimumColumnWidth, columns, data, renderHeader, renderCell, renderActions, isColumnSortable, isRowDeleted, isRowSelected, expectedLength, onRowClick, setActionCellOuiaId, setRowOuiaId, tableOuiaId, children, variant, }: PropsWithChildren<ResponsiveTableProps<TRow, TCol>>) => import("react/jsx-runtime").JSX.Element;
export type ResponsiveThProps = {
    position: number;
    tableWidth: number;
    columnWidth: number;
    canHide: boolean;
} & Omit<ThProps, "ref">;
export declare const ResponsiveTh: import("react").MemoExoticComponent<import("react").ForwardRefExoticComponent<{
    position: number;
    tableWidth: number;
    columnWidth: number;
    canHide: boolean;
} & Omit<ThProps, "ref"> & import("react").RefAttributes<HTMLTableCellElement>>>;
export type ResponsiveTdProps = {
    position: number;
    tableWidth: number;
    columnWidth: number;
    canHide: boolean;
} & Omit<TdProps, "ref">;
export declare const ResponsiveTd: import("react").MemoExoticComponent<import("react").ForwardRefExoticComponent<{
    position: number;
    tableWidth: number;
    columnWidth: number;
    canHide: boolean;
} & Omit<TdProps, "ref"> & import("react").RefAttributes<HTMLTableCellElement>>>;
export type DeletableRowProps = PropsWithChildren<{
    isSelected: boolean;
    isDeleted: boolean;
    onClick?: () => void;
    rowOuiaId?: string;
}>;
export declare const DeletableRow: import("react").NamedExoticComponent<DeletableRowProps>;
export {};
